@@ -1,9 +1,9 @@
 from .exc import TransitionsImplementationError, StateEventImplementationError
 from .events import Event, EpsilonEvent, StateEvent
-from .machines import StateMachine
+from .machines import Moore
 
 __all__ = (
     TransitionsImplementationError, StateEventImplementationError,
     Event, EpsilonEvent, StateEvent,
-    StateMachine
+    Moore
 )
